| Title: | Utilities for Updating R |
|---|---|
| Description: | When updating major or minor R versions all packages should be re-installed. The utilities in this package assist in getting a user up-and-running again by installing all previously installed R packages. The package uses 'renv' to install; immediately replenishing your 'renv' package cache. |
| Authors: | Daniel D. Sjoberg [aut, cre, cph] (ORCID: <https://orcid.org/0000-0003-0862-2018>) |
| Maintainer: | Daniel D. Sjoberg <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2.9000 |
| Built: | 2026-05-31 07:17:03 UTC |
| Source: | https://github.com/ddsjoberg/updater |
The function searches the system paths to find the location of the
previous R version's system library location.
It is not recommended to use this function!
Rather, we recommend that a user simply opens the previous version of R
and runs .libPaths() to find the library location(s).
find_previous_library_location()find_previous_library_location()
package library location
find_previous_library_location()find_previous_library_location()
Provided the location of the previous R installation's package
library, the function will attempt to re-install each of the
packages found. Packages are installed with renv::install()
and will be added to the 'renv' package cache.
Packages can be installed from GitHub, GitLab, BioConductor, and
any repository listed in getOption("repos"). This would typically
be from CRAN and any other secondary repositories that may be set.
install_pkgs(lib.loc = NULL)install_pkgs(lib.loc = NULL)
lib.loc |
character vector describing the location of R library trees to search through |
if (interactive()) { install_pkgs() }if (interactive()) { install_pkgs() }
These functions return the current R version and the the previously installed R version. The format of the returned version matches the default folder name where R is installed.
r_version() previous_r_version()r_version() previous_r_version()
string of R version
r_version() previous_r_version()r_version() previous_r_version()